@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.3"
+    version = "1.8.5"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -113,12 +113,13 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         project = activity.project
         group = activity.group
 
-        self._post(group, project, activity)
+        if activity.data is None:
+            self._post(group, project, activity)
 
     def _post(self, group, project, event=''):
         custom_keyword = self.get_option("custom_keyword", project)
-        # # 告警次数阀值
-        # number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 10
+        # 告警次数阀值
+        number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 1
         phones = self.get_option("phones", project)
         #
         issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
@@ -131,8 +132,8 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title if 'unknown' not in group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
-        payload = f"{payload} > Hi: {event.data} \n\n"
-        payload = f"{payload} > Group: {group.__dict__} \n\n"
+        payload = f"{payload} > Hi: {event.__dict__} \n\n"
+        # payload = f"{payload} > Group: {group.__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
         # payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__} \n\n"
@@ -159,8 +160,6 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
                 except Exception as wrong:
                     return "{\"error\":\"参数不是数字！\"}"
 
-        # 获取预设的阀值
-        # counts = self.get_option("warning_counts", project)
         data_1 = {
             "msgtype": "markdown",
             "markdown": {
@@ -173,7 +172,8 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
             }
 
         }
-        if group.status == 0:
+        # 0 - 状态为未解决，并且次数大于设定值，才告警通知
+        if group.status == 0 and group.times_seen > number_alarm:
             for webhook_url in self.get_webhook_urls(group.project):
                 requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
 
